@@ -6,12 +6,12 @@ use Sub::Util qw(subname);
 use FFI::Platypus;
 use FFI::CheckLib 0.06;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
-my %attr2handler = (
-  Native => sub {},
-  Args => sub {},
-  Returns => sub {},
+my %attr21 = (
+  Native => 1,
+  Args => 1,
+  Returns => 1,
 );
 
 sub _attr_parse {
@@ -24,7 +24,7 @@ sub _attr_parse {
       \)
     )?
   /x);
-  return ($attribute, [ split /,\s*/, $args ]);
+  return ($attribute, [ split /,\s*/, $args//'' ]);
 }
 
 sub MODIFY_CODE_ATTRIBUTES {
@@ -33,7 +33,7 @@ sub MODIFY_CODE_ATTRIBUTES {
   my %attr2args;
   for my $attr (@attrs) {
     my ($attribute, $args) = _attr_parse($attr);
-    if (!$attr2handler{$attribute}) {
+    if (!$attr21{$attribute}) {
       push @bad, $attribute;
       next;
     } else {
@@ -77,14 +77,14 @@ NativeCall - Perl 5 interface to foreign functions in Perl code without XS
   say "Ha! Too slow!";
   cdio_close_tray undef, 0;
 
-  sub fmax :Args(double, double) :Native :Returns(double) {warn "dude2"}
+  sub fmax :Args(double, double) :Native :Returns(double) {}
   say "fmax(2.0, 3.0) = " . fmax(2.0, 3.0);
 
 =head1 DESCRIPTION
 
 Mimics the C<NativeCall> module and interface from Perl 6. Uses
-L<FFI::Platypus> for the actual hard work. Uses inheritance and
-L<attributes>.
+L<FFI::Platypus>, by the mighty Graham Ollis, for the actual hard
+work. Uses inheritance and L<attributes>.
 
 See F<examples/troll.pl> for the example given above in SYNOPSIS.
 
